import React, { useMemo } from 'react';
import classnames from 'classnames';
import uniqueId from 'lodash/uniqueId';
import { parseMetadata } from '@highlight-ui/utils-commons';
import { Typography } from '@highlight-ui/typography';
import noop from 'lodash/noop';

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __rest(s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
}

function __spreadArray(to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
}

var styles$1 = {"checkboxLabelText":"Checkbox-module__1j6zQ7de__v3-0-9","checkbox":"Checkbox-module__1kgWLr7T__v3-0-9","checkboxLabel":"Checkbox-module__2qeuuhJu__v3-0-9","checkboxSubLabel":"Checkbox-module__GJgD8tzu__v3-0-9","checkboxInput":"Checkbox-module__2xgL7bHv__v3-0-9"};

// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
var CheckboxWithRef = function (_a, ref) {
    var label = _a.label, subLabel = _a.subLabel, className = _a.className, metadata = _a.metadata, id = _a.id, checkboxProps = __rest(_a, ["label", "subLabel", "className", "metadata", "id"]);
    var generatedId = useMemo(function () { return uniqueId('checkbox-'); }, []);
    var inputId = id || generatedId;
    return (React.createElement("span", __assign({ className: classnames(className, styles$1.checkbox) }, parseMetadata(metadata)),
        React.createElement("input", __assign({ ref: ref, id: inputId, type: "checkbox", className: styles$1.checkboxInput }, checkboxProps)),
        React.createElement("label", { htmlFor: inputId, className: styles$1.checkboxLabel }, label && (React.createElement(Typography, { title: label, variant: "body-1", component: "span", className: styles$1.checkboxLabelText }, label))),
        label && subLabel && (React.createElement(Typography, { title: subLabel, variant: "body-1", component: "span", className: styles$1.checkboxSubLabel }, subLabel))));
};
CheckboxWithRef.displayName = 'Checkbox';
var Checkbox = React.forwardRef(CheckboxWithRef);

var styles = {"checkboxGroup":"CheckboxGroup-module__n_4k5Q3g__v3-0-9","checkboxGroupOption":"CheckboxGroup-module__1cRRBG-R__v3-0-9","checkboxGroupHorizontal":"CheckboxGroup-module__2uvnJq3Y__v3-0-9"};

var valuesToOptions = function (values, options) {
    return options.filter(function (option) { return values === null || values === void 0 ? void 0 : values.includes(option.value); });
};
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
var CheckboxGroupWithRef = function (_a, ref) {
    var _b;
    var className = _a.className, metadata = _a.metadata, name = _a.name, _c = _a.disabled, disabled = _c === void 0 ? false : _c, _d = _a.orientation, orientation = _d === void 0 ? 'vertical' : _d, options = _a.options, _e = _a.value, value = _e === void 0 ? [] : _e, _f = _a.onChange, onChange = _f === void 0 ? noop : _f;
    var generatedName = useMemo(function () { return uniqueId('CheckboxGroupOption-'); }, []);
    var checkboxGroupName = name || generatedName;
    var selectedOptions = valuesToOptions(value, options);
    return (React.createElement("div", __assign({ ref: ref, className: classnames(className, styles.checkboxGroup, (_b = {},
            _b[styles.checkboxGroupHorizontal] = orientation === 'horizontal',
            _b)) }, parseMetadata(metadata)), options.map(function (option) { return (React.createElement(Checkbox, { key: option.value + "-" + checkboxGroupName, metadata: option.metadata, className: classnames(option.className, styles.checkboxGroupOption), id: option.id, label: option.label, subLabel: option.subLabel, value: option.value, disabled: disabled || option.disabled, checked: value.includes(option.value), name: checkboxGroupName, onChange: function (e) {
            var isChecked = e.currentTarget.checked;
            var newOptions = isChecked
                ? __spreadArray(__spreadArray([], selectedOptions), [option]) : selectedOptions.filter(function (v) { return v.value !== option.value; });
            onChange(newOptions);
        } })); })));
};
CheckboxGroupWithRef.displayName = 'CheckboxGroup';
var CheckboxGroup = React.forwardRef(CheckboxGroupWithRef);

export { Checkbox, CheckboxGroup };
//# sourceMappingURL=index.js.map
